@@ -1,8 +1,7 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- *
+/*
  * This file is part of GtkSourceView
  *
- * Copyright (C) 2003 - Gustavo Giráldez
+ * Copyright 2003 - Gustavo Giráldez
  *
  * GtkSourceView is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,11 +19,9 @@
 
 /* Interface for syntax highlighting engines. */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
-#include "gtksourceengine.h"
+#include "gtksourceengine-private.h"
 #include "gtksourcestylescheme.h"
 
 G_DEFINE_INTERFACE (GtkSourceEngine, _gtk_source_engine, G_TYPE_OBJECT)
@@ -36,51 +33,51 @@ _gtk_source_engine_default_init (GtkSourceEngineInterface *interface)
 
 void
 _gtk_source_engine_attach_buffer (GtkSourceEngine *engine,
-				  GtkTextBuffer   *buffer)
+                                  GtkTextBuffer   *buffer)
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->attach_buffer != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_IFACE (engine)->attach_buffer != NULL);
 
-	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->attach_buffer (engine, buffer);
+	GTK_SOURCE_ENGINE_GET_IFACE (engine)->attach_buffer (engine, buffer);
 }
 
 void
 _gtk_source_engine_text_inserted (GtkSourceEngine *engine,
-				  gint             start_offset,
-				  gint             end_offset)
+                                  gint             start_offset,
+                                  gint             end_offset)
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->text_inserted != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_IFACE (engine)->text_inserted != NULL);
 
-	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->text_inserted (engine,
+	GTK_SOURCE_ENGINE_GET_IFACE (engine)->text_inserted (engine,
 								 start_offset,
 								 end_offset);
 }
 
 void
 _gtk_source_engine_text_deleted (GtkSourceEngine *engine,
-				 gint             offset,
-				 gint             length)
+                                 gint             offset,
+                                 gint             length)
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->text_deleted != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_IFACE (engine)->text_deleted != NULL);
 
-	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->text_deleted (engine,
+	GTK_SOURCE_ENGINE_GET_IFACE (engine)->text_deleted (engine,
 								offset,
 								length);
 }
 
 void
 _gtk_source_engine_update_highlight (GtkSourceEngine   *engine,
-				     const GtkTextIter *start,
-				     const GtkTextIter *end,
-				     gboolean           synchronous)
+                                     const GtkTextIter *start,
+                                     const GtkTextIter *end,
+                                     gboolean           synchronous)
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
 	g_return_if_fail (start != NULL && end != NULL);
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->update_highlight != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_IFACE (engine)->update_highlight != NULL);
 
-	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->update_highlight (engine,
+	GTK_SOURCE_ENGINE_GET_IFACE (engine)->update_highlight (engine,
 								    start,
 								    end,
 								    synchronous);
@@ -88,11 +85,11 @@ _gtk_source_engine_update_highlight (GtkSourceEngine   *engine,
 
 void
 _gtk_source_engine_set_style_scheme (GtkSourceEngine      *engine,
-				     GtkSourceStyleScheme *scheme)
+                                     GtkSourceStyleScheme *scheme)
 {
 	g_return_if_fail (GTK_SOURCE_IS_ENGINE (engine));
 	g_return_if_fail (GTK_SOURCE_IS_STYLE_SCHEME (scheme) || scheme == NULL);
-	g_return_if_fail (GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->set_style_scheme != NULL);
+	g_return_if_fail (GTK_SOURCE_ENGINE_GET_IFACE (engine)->set_style_scheme != NULL);
 
-	GTK_SOURCE_ENGINE_GET_INTERFACE (engine)->set_style_scheme (engine, scheme);
+	GTK_SOURCE_ENGINE_GET_IFACE (engine)->set_style_scheme (engine, scheme);
 }
